@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.1234';
+our $VERSION = '0.12345';
 use 5.006;
 use strict;
 use warnings;
@@ -337,7 +337,9 @@ sub _bless_tree {
 
 sub TO_JSON {
 	my $self = shift;
-	return [@$self] if reftype $self eq 'ARRAY';
+	my $ref = reftype $self;
+	return $self unless $ref && $ref =~ m/ARRAY|HASH/;
+	return [@$self] if $ref eq 'ARRAY';
 	return 'cannot stringify application object' if $self->{_application};
 	my $output = {};
 	my $nodebug = ! $self->{_debug};
@@ -379,7 +381,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.1234
+Version 0.12345
 
 =cut
 
